@@ -3,7 +3,7 @@
 package Math::BigInt::Constant;
 my $class = "Math::BigInt::Constant";
 
-$VERSION = 1.05;
+$VERSION = 1.06;
 use Math::BigInt;
 @ISA =       qw( Math::BigInt );
 use strict;
@@ -61,7 +61,7 @@ Math::BigInt::Constant - Arbitrary sized constant integers
   $x->is_even();		# return true if even, false for odd
   $x->is_inf($sign);		# return true if argument is +inf or -inf, give
 				# argument ('+' or '-') to match only same sign
-  $x->is_pos();			# return true if arg >= 0
+  $x->is_pos();			# return true if arg > 0
   $x->is_neg();			# return true if arg < 0
 
   $x->bcmp($y);			# compare numbers (undef,<0,=0,>0)
@@ -118,29 +118,34 @@ Math::BigInt::Constant - Arbitrary sized constant integers
   $x->digit($n);		# extract N'th digit from number
   
   $x->as_int();			# return a copy of the object as BigInt
+  $x->as_hex();			# return number as hex string
+  $x->as_bin();			# return number as binary string
 
 =head1 DESCRIPTION
 
-This module let's you defined constant BigInt's on a per-object basis. The
+With this module you can define constant BigInts on a per-object basis. The
 usual C<use Math::BigInt ':constant'> will catch B<all> integer constants
 in the script at compile time, but will not let you create constant values
 on the fly, nor work for strings and/or floating point constants like C<1e5>.
 
+C<Math::BigInt::Constant> is a true subclass of L<Math::BigInt> and can do all
+the same things - except modifying any of the objects.
+
 =head1 EXAMPLES
  
 Opposed to compile-time checking via C<use constant>:
 
 	use Math::BigInt;
-	use constant X => Math::BigInt->new(12345678);
+	use constant X => Math::BigInt->new("12345678");
 
 	print X," ",X+2,"\n";		# okay
 	print "X\n";			# oups
+	X += 2;				# not okay, will die
 
 these provide runtime checks and can be interpolated into strings:
 
 	use Math::BigInt::Constant;
-
-	$x = Math::BigInt::Constant->new(3141592);
+	$x = Math::BigInt::Constant->new("3141592");
 
 	print "$x\n";			# okay
 	print $x+2,"\n";		# dito
@@ -150,8 +155,12 @@ these provide runtime checks and can be interpolated into strings:
 
 None discovered yet.
 
+=head1 SEE ALSO
+
+L<Math::BigInt>.
+
 =head1 AUTHORS
 
-(c) by Tels http://bloodgate.com in early 2001, 2002, 2004.
+(c) by Tels L<http://bloodgate.com/> in early 2001 - 2005.
 
 =cut
